import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useEffect, useMemo } from "react";
import SequenceAnnotator from "../SequenceAnnotator";
import DocumentLabeler from "../DocumentLabeler";
import Transcriber from "../Transcriber";
import colors from "../../colors";
import Container from "../Container";
import useEventCallback from "use-event-callback";

var defaultValidator = function defaultValidator() {
  return [];
};

export default function NLPAnnotator(props) {
  var validator = props.validator || defaultValidator;

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      output = _useState2[0],
      changeOutput = _useState2[1];

  if (output === null && props.type === "transcribe") {
    output = props.initialTranscriptionText;
  }

  if (output === null && props.type === "label-sequence") {
    output = props.initialSequence || [{
      text: props.document
    }];
  }

  useEffect(function () {
    var eventFunc = function eventFunc(e) {
      if (e.key === "Enter") {
        if (props.onFinish) props.onFinish(output);
      }
    };

    window.addEventListener("keydown", eventFunc);
    return function () {
      window.removeEventListener("keydown", eventFunc);
    };
  }, [props.onFinish, output]);

  var onChange = function onChange(newOutput) {
    if (props.onChange) props.onChange(newOutput);
    changeOutput(newOutput);
  };

  var labels = useMemo(function () {
    var labels = props.labels || [];

    if (!labels.some(function (l) {
      return !l.color;
    })) {
      labels = labels.map(function (l, i) {
        return _objectSpread({}, l, {
          color: colors[i % colors.length]
        });
      });
    }

    return labels;
  }, [props.labels]);
  var isPassingValidation = !validator(output).some(function (msg) {
    return msg.toLowerCase().includes("error");
  });
  console.log({
    output: output
  });
  var onFinish = useEventCallback(function () {
    if (!isPassingValidation) return;
    console.log("onFinish", output);
    props.onFinish(output);
  });
  var onClickHeaderItem = useEventCallback(function (_ref) {
    var name = _ref.name;

    switch (name) {
      case "Done":
        onFinish(output);
        return;

      default:
        return;
    }
  });
  var annotator;

  switch (props.type) {
    case "label-sequence":
      annotator = /*#__PURE__*/React.createElement(SequenceAnnotator, Object.assign({}, props, {
        labels: labels,
        onChange: onChange
      }));
      break;

    case "label-document":
      annotator = /*#__PURE__*/React.createElement(DocumentLabeler, Object.assign({}, props, {
        labels: labels,
        onChange: onChange
      }));
      break;

    case "transcribe":
      annotator = /*#__PURE__*/React.createElement(Transcriber, Object.assign({}, props, {
        onChange: onChange
      }));
      break;

    default:
      annotator = null;
  }

  return /*#__PURE__*/React.createElement(Container, {
    titleContent: props.titleContent,
    onNext: props.onNext,
    onPrev: props.onPrev,
    onClickHeaderItem: onClickHeaderItem
  }, /*#__PURE__*/React.createElement("div", null, annotator));
}